@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_lambda._jsii
@@ -18,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-lambda-step-function",
-    "1.61.0",
+    "1.62.0",
     __name__[0:-6],
-    "aws-lambda-step-function@1.61.0.jsii.tgz",
+    "aws-lambda-step-function@1.62.0.jsii.tgz",
 )
 
 __all__ = [
